@@ -368,7 +368,8 @@ do_tell (GnomeVFSMethod *method,
 }
 
 
-/* FIXME: This function works around a problem in gnome-vfs where you
+/* FIXME bugzilla.eazel.com 2615:
+   This function works around a problem in gnome-vfs where you
  * can't get the original URI without added slashes. That problem
  * should be fixed and then this can be removed.
  */
@@ -414,12 +415,10 @@ do_open_directory (GnomeVFSMethod *method,
 
 	default:
 	case SEARCH_URI_TYPE_TOP_LEVEL:
-		connection = medusa_search_service_connection_new (&result);
-		if (result != GNOME_VFS_OK) {
-			return result;
-		}
+
 		
-		/* FIXME: Since medusa already knows about search
+		/* FIXME bugzilla.eazel.com 2616:
+		   Since medusa already knows about search
 		 * URIs, the escaped character handling should be done
 		 * there. We should just pass the URI text as-is and
 		 * not unescape it ourselves.
@@ -427,9 +426,16 @@ do_open_directory (GnomeVFSMethod *method,
 		uri_text = uri_to_string_remove_extra_slashes (uri);
 		unescaped_uri_text = gnome_vfs_unescape_string (uri_text, NULL);
 		g_free (uri_text);
-
-		result = medusa_search_service_connection_start_search (connection, unescaped_uri_text);
+		connection = medusa_search_service_connection_new (unescaped_uri_text,
+								   &result);
 		g_free (unescaped_uri_text);
+		if (result != GNOME_VFS_OK) {
+
+			return result;
+		}
+		result = medusa_search_service_connection_start_search (connection);
+
+
 
 		if (result == GNOME_VFS_OK) {
 			*method_handle = (GnomeVFSMethodHandle *) search_real_directory_handle_new
@@ -478,16 +484,22 @@ get_file_info_for_virtual_directory (GnomeVFSFileInfo *file_info)
 	GNOME_VFS_FILE_INFO_SET_LOCAL (file_info, TRUE);
 	file_info->uid = getuid();
 	file_info->gid = getgid();
-	/* FIXME: Is it OK to always return the MIME type and ignore
-	 * the options setting?
+	file_info->mtime = time (NULL);
+
+	/* FIXME bugzilla.eazel.com 2617:
+	   We should only set the mime type here if 
+	   the caller requests the mime type for
+	   consistency
 	 */
 	g_assert (file_info->mime_type == NULL);
-	file_info->mime_type = g_strdup ("x-special/virtual-directory");
+	file_info->mime_type = g_strdup ("x-directory/search");
 	
 	file_info->valid_fields = GNOME_VFS_FILE_INFO_FIELDS_TYPE
 		| GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS
 		| GNOME_VFS_FILE_INFO_FIELDS_FLAGS
+		| GNOME_VFS_FILE_INFO_FIELDS_MTIME
 		| GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE;
+
 }
 
 static void
@@ -504,7 +516,8 @@ get_file_info_for_virtual_link (GnomeVFSFileInfo *file_info, const char *target_
 	GNOME_VFS_FILE_INFO_SET_LOCAL (file_info, TRUE);
 	file_info->uid = getuid();
 	file_info->gid = getgid();
-	/* FIXME: The gnome-vfs symlink_name field holds a path only
+	/* FIXME bugzilla.eazel.com 2618:
+	   The gnome-vfs symlink_name field holds a path only
 	 * (not a URI). This means that the search results must all be
 	 * on the local file system. Luckily, they are at the moment
 	 * due to limitations in medusa, but this may have to be dealt
@@ -512,8 +525,9 @@ get_file_info_for_virtual_link (GnomeVFSFileInfo *file_info, const char *target_
 	 */
 	g_assert (file_info->symlink_name == NULL);
 	file_info->symlink_name = g_strdup (gnome_vfs_uri_get_path (target_uri));
-	/* FIXME: Is it OK to always return the MIME type and ignore
-	 * the options setting?
+	/* FIXME bugzilla.eazel.com 2617:
+	   We should check the mode before returning the
+	   mime type for consistency
 	 */
 	g_assert (file_info->mime_type == NULL);
 	file_info->mime_type = g_strdup ("x-special/symlink");
@@ -548,7 +562,8 @@ do_read_directory (GnomeVFSMethod *method,
 			(wrapped_handle->u.real.connection, &result_uri);
 
 		if (result == GNOME_VFS_OK) {
-			/* FIXME: Add code to do filtering. Only the
+			/* FIXME bugzilla.eazel.com 2619:
+			   Add code to do filtering. Only the
 			 * file method currently implements filtering
 			 * so no one can really use it with an
 			 * arbitrary directory handle anyway, so there
@@ -579,6 +594,10 @@ do_read_directory (GnomeVFSMethod *method,
 				file_info->name = gnome_vfs_escape_string (result_uri);
 			}
 
+			if (result == GNOME_VFS_OK) {
+				g_assert ((file_info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_FLAGS) != 0);
+				GNOME_VFS_FILE_INFO_SET_SYMLINK (file_info, TRUE);
+			}
 			g_free (result_uri);
 		}
 	}
@@ -621,7 +640,7 @@ do_get_file_info (GnomeVFSMethod *method,
 		get_file_info_for_virtual_directory (file_info);
 		/* Need a check here to make sure the search service
 		   is really running before returning any information */
-		result = medusa_search_service_connection_is_available ();
+		result = medusa_search_service_connection_is_available_for_uri (uri);
 		break;
 	case SEARCH_URI_TYPE_IMMEDIATE_CHILD:
 		if ((options & GNOME_VFS_FILE_INFO_FOLLOW_LINKS) == 0) {
@@ -643,6 +662,10 @@ do_get_file_info (GnomeVFSMethod *method,
 			g_free (file_info->name);
 			file_info->name = gnome_vfs_escape_string (child_uri_text);
 		}
+		if (result == GNOME_VFS_OK) {
+			g_assert ((file_info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_FLAGS) != 0);
+			GNOME_VFS_FILE_INFO_SET_SYMLINK (file_info, TRUE);
+		}
 		break;
 	case SEARCH_URI_TYPE_DEEPER_CHILD:
 		result = get_file_info_cancellable_cover (child_uri_text,
@@ -702,7 +725,8 @@ do_is_local (GnomeVFSMethod *method,
 	case SEARCH_URI_TYPE_IMMEDIATE_CHILD:
 		break;
 	case SEARCH_URI_TYPE_DEEPER_CHILD:
-		/* FIXME: This should call through to the underlying
+		/* FIXME bugzilla.eazel.com 2620:
+		   This should call through to the underlying
 		 * file system, but there's no nice
 		 * gnome_vfs_is_local_cancellable call to use.
 		 */
@@ -936,6 +960,7 @@ do_find_directory (GnomeVFSMethod *method,
 		   GnomeVFSFindDirectoryKind kind,
 		   GnomeVFSURI **result_uri,
 		   gboolean create_if_needed,
+		   gboolean find_if_needed,
 		   guint permissions,
 		   GnomeVFSContext *context)
 {
@@ -952,7 +977,8 @@ do_find_directory (GnomeVFSMethod *method,
 		break;
 	case SEARCH_URI_TYPE_DEEPER_CHILD:		
 		vfs_uri = gnome_vfs_uri_new (child_uri_text);
-		result = gnome_vfs_find_directory_cancellable (vfs_uri, kind, result_uri, create_if_needed, permissions, context);
+		result = gnome_vfs_find_directory_cancellable (vfs_uri, kind, result_uri, 
+			create_if_needed, find_if_needed, permissions, context);
 		gnome_vfs_uri_unref (vfs_uri);
 		break;
 	}
