@@ -32,12 +32,14 @@
 #include "medusa-uri-list.h"
 #include "medusa-file-index.h"
 
-
+#include <libmedusa/medusa-index-progress.h>
 
 struct MedusaMasterDB {
 	MedusaTextIndex *text_index;
 	MedusaFileSystemDB *file_system_db;
 	MedusaURIList *uri_list;
+	gboolean indexing_mode;
+	MedusaIndexProgress *index_progress;
 	char *root_uri;
 	MedusaLogLevel log_level;
 	int ref_count;
