@@ -20,24 +20,23 @@
  *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *  Authors: Rebecca Schulman <rebecka@eazel.com>
- *           Maciej Stachowiak <mjs@eazel.com> 
  *  
  */
 
 
-/* medusa-index-service-private.h -- things that are internal to the
-   index service client implementation and need to be shared with the
-   indexer daemon. */
+/* medusa-index-service-private.h -- Internal constants related to
+   the communication protocol */
 
 #ifndef MEDUSA_INDEX_SERVICE_PRIVATE_H
 #define MEDUSA_INDEX_SERVICE_PRIVATE_H
 
-#include <libmedusa/medusa-common-private.h>
+#define INDEX_SOCKET_PATH "/tmp/medusa-index-server"
 
-#define INDEX_SOCKET_PATH  "/tmp/medusa-index-server"
+#define MEDUSA_REINDEX_REQUEST      "Create new index now\n"
+#define MEDUSA_REINDEX_REQUEST_ACCEPTED "Reindexing now\n"
+#define MEDUSA_REINDEX_REQUEST_DENIED_BUSY "Cannot reindex right now\n"
+
+#define MEDUSA_LAST_INDEX_UPDATE_TIME_REQUEST "Get last indexing time\n"
 
-#define MEDUSA_FILE_REINDEX_REQUEST      "update file data"
-#define MEDUSA_TOTAL_REINDEX_REQUEST     "totally reindex"
 
 #endif /* MEDUSA_INDEX_SERVICE_PRIVATE_H */
-
